pyxmpp2.sasl.core.ServerAuthenticator

Package pyxmpp2 :: Package sasl :: Module core :: Class ServerAuthenticator |
[hide private]

# Class ServerAuthenticator

Base class for server authenticators.

A server authenticator class is a server-side implementation of a SASL mechanism. One ServerAuthenticator object may be used for one client authentication process.

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a ServerAuthenticator object. |
Challenge or Failure or Success |
start(self, initial_response) Start the authentication process. |
Challenge or Success or Failure |
response(self, response) Process a response from a client. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x879026c>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x87902ac>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x879020c>`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) |
Initialize a ServerAuthenticator object. Parameters: `password_manager` (PasswordManager) - a password manager providing authentication credential verfication. Overrides: object.__init__

### start(self, initial_response) |
Start the authentication process. Parameters: `initial_response` (`bytes`) - the initial response send by the client with the authentication request. Returns: Challenge or Failure or Success a challenge, a success or a failure indicator.

### response(self, response) |
Process a response from a client. Parameters: `response` (`bytes`) - the response from the client to our challenge. Returns: Challenge or Success or Failure a challenge, a success or a failure indicator.